@@ -5,10 +5,12 @@
 #' @usage
 #' import.meas(file, info.data,
 #'             n.chamber = c(1,2,3,4,5,6,7,8),
-#'             logger = c("AutoResp", "FishResp"),
+#'             logger = c("AutoResp", "FishResp", "Qbox-Aqua"),
 #'             date.format = c("DMY", "MDY", "YMD"),
 #'             start.measure = "00:00:00",
 #'             stop.measure = "23:59:59",
+#'             set.date.time = NA,
+#'             meas.to.wait = 0,
 #'             plot.temperature = TRUE,
 #'             plot.oxygen = TRUE)
 #'
@@ -17,15 +19,35 @@
 #' @param n.chamber  integer: the number of chambers used in an experiment (including empty ones)
 #' @param logger  string: the name of a logger software used for intermittent-flow respirometry
 #' \itemize{
-#'   \item 'AutoResp' if you use commercial software of 'Loligo Systems'
-#'   \item 'FishResp' if you do not use the above-mentioned software, standardize data to the format described below (see Details in the\cr function \code{\link{import.test}})
+#'   \item 'AutoResp' if you use commercial software by 'Loligo Systems'
+#'   \item 'FishResp' if you use free software 'AquaResp' in combination with equipment produced by 'PreSens' or 'Pyroscience', please convert data to the 'FishResp' format using the functions \code{\link{presens.aquaresp}} or \code{\link{pyroscience.aquaresp}}, respectively. \cr If you do not use commercial software or AquaResp for running intermittent-flow respirometry, adjust raw data manually to the 'FishResp' format (see Details below).
+#'   \item 'Qbox-Aqua' if you use commercial software by 'Qubit Systems'
 #' }
 #' @param date.format  string: date format (DMY, MDY or YMD)
 #' @param start.measure  chron: time when metabolic rate measurements are started
 #' @param stop.measure  chron: time when metabolic rate measurements are finished
+#' @param set.date.time  chron: this parameter is turned off by default and needed to be specified only if raw data were recorded by 'Qbox-Aqua' logger software. Specifically, input the date and time when .cmbl file was built in one of the following formats: "dd/mm/yyyy/hh:mm:ss", "mm/dd/yyyy/hh:mm:ss", or "yyyy/mm/dd/hh:mm:ss" (in accourdance to the chosen date.format parameter).
+#' @param meas.to.wait  integer: the number of first rows for each measurement phase ('M') which should be reassigned to the wait phase (W). The parameter should be used when the wait phase ('W') is absent (e.g. in 'Qbox-Aqua' logger software) or not long enough to eliminate non-linear change in DO concentration over time from the measurement phase ('M') after shutting off water supply from the ambient water source.
 #' @param plot.temperature  logical: if TRUE then the graph of raw temperature data is plotted
 #' @param plot.oxygen  logical: if TRUE then the graph of raw oxygen data is plotted
 #'
+#' @details If you use closed respirometry approach, please standardize raw data. The example of "FishResp" format for 4-channel respirometry system is shown here:
+#' \tabular{cccccccccc}{
+#'   Date&Time \tab Phase \tab Temp.1 \tab Ox.1 \tab Temp.2 \tab Ox.2 \tab Temp.3 \tab Ox.3 \tab Temp.4 \tab Ox.4\cr
+#'   19/08/2016/18:47:20 \tab F1 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73\cr
+#'   19/08/2016/18:47:21 \tab F1 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73\cr
+#'   19/08/2016/18:47:22 \tab M1 \tab 24.49 \tab 7.77 \tab 24.56 \tab 7.72 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73\cr
+#'   19/08/2016/18:47:23 \tab M1 \tab 24.49 \tab 7.76 \tab 24.56 \tab 7.72 \tab 24.49 \tab 7.78 \tab 24.56 \tab 7.73\cr
+#' } where the items are:
+#' \itemize{
+#' \item Time step-interval is one second: one row of data per second.
+#' \item Date&Time should be represented in one of the following formats: "dd/mm/yyyy/hh:mm:ss", "mm/dd/yyyy/hh:mm:ss", or "yyyy/mm/dd/hh:mm:ss".
+#' \item Phase should have at least two levels: M (measurement) and F (flush). The number of a period should be attached to the level of a phase: F1, M1, F2, M2 ...
+#' \item Ox.1 contains values of dissolved oxygen measured in 'mg/L', 'mmol/L' or 'ml/L' for Chamber 1. If other measurement units were used, convert them to 'mg/L', 'mmol/L' or 'ml/L' using the function \code{\link{convert.respirometry}} or \code{\link{convert.rMR}}.
+#' \item Temp.1 contains values of water temperature in Celsius (C) for Chamber 1
+#' \item ...
+#' }
+#'
 #' @return The function returns a data frame containing standardized raw data of metabolic rate measurements. The data frame should be used in the function \code{\link{correct.meas}} to correct metabolic rate measurements for background respiration.
 #'
 #' @importFrom chron chron
@@ -62,14 +84,30 @@
 #'                        plot.temperature = TRUE,
 #'                        plot.oxygen = TRUE)
 #'
+#' # an example for importting raw data recorded by Qbox-Aqua
+#' qbox.path = system.file("extdata/qbox-aqua/qbox-aqua.csv", package = "FishResp")
+#' RMR.raw <- import.meas(file = qbox.path,
+#'                         info.data = info,
+#'                         logger = "Qbox-Aqua",
+#'                         n.chamber = 1,
+#'                         date.format = "DMY",
+#'                         start.measure = "20:00:00",
+#'                         stop.measure = "08:00:00",
+#'                         set.date.time = "23/02/2014/23:30:22",
+#'                         meas.to.wait = 100,
+#'                         plot.temperature = TRUE,
+#'                         plot.oxygen = TRUE)
+#'
 #' @export
 
 import.meas <- function(file, info.data,
                         n.chamber = c(1,2,3,4,5,6,7,8),
-                        logger = c("AutoResp", "FishResp"),
+                        logger = c("AutoResp", "FishResp", "Qbox-Aqua"),
                         date.format = c("DMY", "MDY", "YMD"),
                         start.measure = "00:00:00",
                         stop.measure = "23:59:59",
+                        set.date.time = NA,
+                        meas.to.wait = 0,
                         plot.temperature = TRUE,
                         plot.oxygen = TRUE){
 
@@ -272,8 +310,40 @@ import.meas <- function(file, info.data,
     }
   }
 
+  ### Qbox-Aqua format ###
+
+  else if (logger == "Qbox-Aqua"){
+    MR.data.all<-read.table(file, sep = ",", skip=2, header=F, strip.white=T)
+    if (n.chamber == 1){
+      MR.data.all<-subset(MR.data.all, select=c(V1, V9, V4, ncol(MR.data.all)))
+      names(MR.data.all)<-c("Date.Time", "Phase", "Temp.1", "Ox.1")
+      for(i in 3:ncol(MR.data.all)){MR.data.all[,i] = as.numeric(gsub(',','.', MR.data.all[,i]))}
+      aaa <- max(MR.data.all$Ox.1, na.rm = TRUE)
+      if(all(is.na(MR.data.all$Ox.1))){MR.data.all$Ox.1[is.na(MR.data.all$Ox.1)] <- aaa}
+
+      ### Indexing measurement phases for Qbox-Aqua
+      MR.data.all$Phase[MR.data.all$Phase == "1"] <- "F"
+      MR.data.all$Phase[MR.data.all$Phase == "0"] <- "M"
+      bdrs <- which(c(FALSE, tail(MR.data.all$Phase,-1) != head(MR.data.all$Phase,-1)))
+      bdrs <- paste(bdrs , MR.data.all$Phase[bdrs], sep = "")
+      M.start <- grep('M', bdrs, value=TRUE)
+      M.start <- as.integer(sub("M$", "", M.start))
+      M.end <- grep('F', bdrs, value=TRUE)
+      M.end <- as.integer(sub("F$", "", M.end)) - 1
+      if(M.end[1] < M.start[1]){M.end <- M.end[-1]}
+
+      for(i in 1:length(M.end)){
+        MR.data.all$Phase[M.start[i]:M.end[i]] <- paste(MR.data.all$Phase[M.start[i]:M.end[i]], i, sep = "")
+      }
+    }
+    else{
+      print("If 'Qubit Systems' starts producing multi-chamber systems for aquatic respirometry, please contact us via email: fishresp@gmail.com")
+    }
+  }
+
+
   else{
-    print("Please, choose the format of your data: AutoResp or FishResp")
+    print("Please, choose the format of your data: AutoResp, FishResp or Qbox-Aqua")
   }
 
   rm(aaa)
@@ -291,15 +361,57 @@ import.meas <- function(file, info.data,
   if(PM.1 || PM.2 || PM.3 || PM.4 == TRUE){
 
     if(any(date.format == "DMY")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%d/%m/%Y/ %I:%M:%S %p")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%d/%m/%Y/ %I:%M:%S %p")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%d/%m/%Y/ %I:%M:%S %p")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%d/%m/%y"), format="d/m/y")
     }
     else if(any(date.format == "MDY")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%m/%d/%Y/ %I:%M:%S %p")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%m/%d/%Y/ %I:%M:%S %p")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%m/%d/%Y/ %I:%M:%S %p")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%m/%d/%y"), format="m/d/y")
     }
     else if(any(date.format == "YMD")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%Y/%m/%d/ %I:%M:%S %p")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%Y/%m/%d/ %I:%M:%S %p")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%Y/%m/%d/ %I:%M:%S %p")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%y/%m/%d"), format="y/m/d")
     }
     else{
@@ -308,15 +420,57 @@ import.meas <- function(file, info.data,
   }
   else{
     if(any(date.format == "DMY")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%d/%m/%Y/%H:%M:%S")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%d/%m/%Y/%H:%M:%S")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%d/%m/%Y/%H:%M:%S")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%d/%m/%y"), format="d/m/y")
     }
     else if(any(date.format == "MDY")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%m/%d/%Y/%H:%M:%S")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%m/%d/%Y/%H:%M:%S")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%m/%d/%Y/%H:%M:%S")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%m/%d/%y"), format="m/d/y")
     }
     else if(any(date.format == "YMD")){
-      MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%Y/%m/%d/%H:%M:%S")
+      if(logger == "Qbox-Aqua"){
+        crdt<-strptime(as.character(set.date.time), "%Y/%m/%d/%H:%M:%S")
+        crdt <- rep(crdt, length(MR.data.all$Date.Time))
+        crdt$sec <- crdt$sec + MR.data.all$Date.Time
+          if(any(crdt$sec == 60)){
+            s<-which(crdt$sec == 60)
+            crdt$sec[s] = 0
+            crdt$min[s] = crdt$min[s]+1
+          }else{
+            }
+        MR.data.all$Date.Time <- crdt
+      }
+      else{
+        MR.data.all$Date.Time<-strptime(as.character(MR.data.all$Date.Time), "%Y/%m/%d/%H:%M:%S")
+      }
       dts<-dates(strftime(MR.data.all$Date.Time, "%y/%m/%d"), format="y/m/d")
     }
     else{
@@ -376,6 +530,15 @@ import.meas <- function(file, info.data,
     a <- paste("M", i, sep = "")
     ifelse(MR.data.all$Phase==a, x <- a, i<-i+1)
   }
+
+  # cut off first n raws from 'M' phase
+  if(meas.to.wait != 0){
+    idx <- unlist(tapply(1:nrow(MR.data.all), MR.data.all$Phase, tail, -(meas.to.wait)), use.names=FALSE)
+    MR.data.all <- MR.data.all[idx, ]
+  }else{
+    }
+  row.names(MR.data.all) <- 1:nrow(MR.data.all)
+
   MR.data.all$Time<-rep(1:1:length(subset(MR.data.all, Phase == x)$Ox.1), length(levels(MR.data.all$Phase)))
   rm(x)
 
